@@ -47,6 +47,14 @@ def proto(path):
     from spectre.generation import proto
     proto.generate(CONFIG, path)
 
+@click.command()
+@click.argument('path')
+def liquibase(path):
+    from spectre.generation import liquibase
+    written = liquibase.generate(CONFIG, path)
+    for path in written:
+        click.echo(path)
+
 @click.command()
 @click.argument('path')
 @click.option('--pojo', is_flag=True, help='Generate the base model java class corresponding to the entity')
@@ -91,4 +99,5 @@ create.add_command(create_config)
 generate.add_command(java)
 generate.add_command(jhipster)
 generate.add_command(proto)
+generate.add_command(liquibase)
 cli()
